@@ -57,7 +57,9 @@
 #'
 #' prioritize(matched, priority = bad_idea)
 prioritize <- function(data, priority = NULL) {
-  if (has_cero_rows(data)) return(data)
+  if (has_zero_rows(data)) {
+    return(data)
+  }
 
   data %>%
     check_crucial_names(
@@ -78,25 +80,26 @@ prioritize <- function(data, priority = NULL) {
   group_by(out, !!!old_groups)
 }
 
-has_cero_rows <- function(data) {
+has_zero_rows <- function(data) {
   !nrow(data) > 0L
 }
 
 check_duplicated_score1 <- function(data) {
-  is_duplicated <- data %>%
-    filter(.data$score == 1) %>%
-    select(.data$id_loan, .data$level) %>%
-    duplicated()
+  score_1 <- filter(data, .data$score == 1)
+  # The only important side effect of this function if to abort duplicated rows
+  loan_level <- suppressMessages(select(score_1, .data$id_loan, .data$level))
+  is_duplicated <- duplicated(loan_level)
 
   if (!any(is_duplicated)) {
     return(invisible(data))
   }
 
+  duplicated_rows <- commas(rownames(data)[is_duplicated])
   abort(
     class = "duplicated_score1_by_id_loan_by_level",
     message = glue(
       "`data` where `score` is `1` must be unique by `id_loan` by `level`.
-     Duplicated rows: {commas(rownames(data)[is_duplicated])}.
+     Duplicated rows: {duplicated_rows}.
      Have you ensured that only one ald-name per loanbook-name is set to `1`?"
     )
   )
